#!D:\bld\gdal-split_1615355268532\_h_env\python.exe
# EASY-INSTALL-SCRIPT: 'GDAL==3.2.1','gdalmove.py'
__requires__ = 'GDAL==3.2.1'
__import__('pkg_resources').run_script('GDAL==3.2.1', 'gdalmove.py')
